@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Util;
 
-our $DATE = '2017-01-07'; # DATE
-our $VERSION = '0.12'; # VERSION
+our $DATE = '2017-01-09'; # DATE
+our $VERSION = '0.13'; # VERSION
 
 use 5.010001;
 use strict;
@@ -171,13 +171,27 @@ sub detect_pericmd_script {
                            JSON::MaybeXS::decode_json($pericmd_inline_attrs) };
                 if ($@) {
                     push @{ $meta->{'func.notes'} },
-                        "Can't parse # PERICMD_INLINE_SCRIPT attributes: $@";
+                        "Can't parse # PERICMD_INLINE_SCRIPT line: $@";
                 } else {
                     $meta->{'func.pericmd_inline_attrs'} =
                         $pericmd_inline_attrs;
                 }
             }
 
+            if ($str =~ /^# PERICMD_INLINE_SCRIPT_METAS: (.+)/m) {
+                my $pericmd_inline_metas = $1;
+                require JSON::MaybeXS;
+                eval { $pericmd_inline_metas =
+                           JSON::MaybeXS::decode_json($pericmd_inline_metas) };
+                if ($@) {
+                    push @{ $meta->{'func.notes'} },
+                        "Can't parse # PERICMD_INLINE_SCRIPT_METAS line: $@";
+                } else {
+                    $meta->{'func.pericmd_inline_metas'} =
+                        $pericmd_inline_metas;
+                }
+            }
+
             last DETECT;
         }
         $reason = "Can't find any statement requiring Perinci::CmdLine".
@@ -210,7 +224,7 @@ Perinci::CmdLine::Util - Utility routines related to Perinci::CmdLine
 
 =head1 VERSION
 
-This document describes version 0.12 of Perinci::CmdLine::Util (from Perl distribution Perinci-CmdLine-Util), released on 2017-01-07.
+This document describes version 0.13 of Perinci::CmdLine::Util (from Perl distribution Perinci-CmdLine-Util), released on 2017-01-09.
 
 =head1 SYNOPSIS
 
